==> nextcloud-18.0.4.tgz: nextcloud/apps/serverinfo/l10n/de.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average" : "Durchschnittsauslastung",
    "Last minute" : "Letzte Minute",
    "Memory info not available" : "Informationen zum Arbeitsspeicher nicht verfügbar",
    "Total" : "Gesamt",
    "Current usage" : "Aktuelle Nutzung",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Links" : "Verknüpfungen",
    "Mails" : "E-Mails",
    "Federated sent" : "Federated gesendet",
    "Federated received" : "Federated empfangen",
    "Talk conversations" : "Talk Unterhaltungen",
    "24 hours" : "24 Stunden",
    "1 hour" : "1 Stunde",
    "5 mins" : "5 Minuten",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System" : "Betriebssystem",
    "CPU" : "Prozessor",
    "Memory" : "Speicher",
    "Server time" : "Server-Zeit",
    "Uptime" : "Betriebszeit",
    "Time Servers" : "Zeitserver",
    "Load" : "Auslastung",
    "Disk" : "Festplatte",
    "Mount" : "Mount",
    "Filesystem" : "Dateisystem",
    "Size" : "Größe",
    "Available" : "Verfügbar",
    "Used" : "Verwendet",
    "You will get a notification once one of your disks is nearly full." : "Du erhältst eine Benachrichtigung sobald eine Deiner Speichermedien fast voll ist.",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname" : "Host-Name",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Geschwindigkeit",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktive Benutzer",
    "Total users:" : "Nutzer gesamt:",
    "Shares" : "Freigaben",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory Limit:" : "Arbeitspeicher-Grenzwert:",
    "Max Execution Time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "Size:" : "Größe:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Did you know?" : "Wusstest Du schon?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Das Anhängen von \"?format=json\" am Ende der URL gibt Dir das Ergebnis im JSON-Format!",
    "Last 24 hours" : "Letzte 24 Stunden",
    "Last 1 hour" : "Letzte Stunde",
    "Last 5 mins" : "Letzte 5 Minuten",
    "CPU load" : "CPU-Auslastung",
    "Memory usage" : "Arbeitsspeicher-Auslastung",
    "Storage" : "Speicher",
    "Users:" : "Benutzer:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Installierte Apps:",
    "Apps updates available:" : "Apps mit verfügbaren Aktualisierungen:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-18.0.9.tgz: nextcloud/apps/serverinfo/l10n/de.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informationen zur CPU nicht verfügbar",
    "Load average" : "Durchschnittsauslastung",
    "Last minute" : "Letzte Minute",
    "Memory info not available" : "Informationen zum Arbeitsspeicher nicht verfügbar",
    "Total" : "Gesamt",
    "Current usage" : "Aktuelle Nutzung",
    "Users" : "Benutzer",
    "Groups" : "Gruppen",
    "Links" : "Verknüpfungen",
    "Mails" : "E-Mails",
    "Federated sent" : "Federated gesendet",
    "Federated received" : "Federated empfangen",
    "Talk conversations" : "Talk Unterhaltungen",
    "24 hours" : "24 Stunden",
    "1 hour" : "1 Stunde",
    "5 mins" : "5 Minuten",
    "Copy" : "Kopieren",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "⌘-C zum Kopieren drücken.",
    "Press Ctrl-C to copy." : "Ctrl-C zum Kopieren drücken.",
    "System" : "System",
    "Monitoring" : "Information",
    "Monitoring app with useful server information" : "Monitoring-App mit nützlichen Serverinformationen",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Zeigt nützliche Informationen des Servers an wie z.B. CPU-Last, Arbeitsspeicherauslastung, Massenspeicherauslastung, Anzahl der Benutzer, usw.",
    "Operating System" : "Betriebssystem",
    "CPU" : "Prozessor",
    "Memory" : "Speicher",
    "Server time" : "Server-Zeit",
    "Uptime" : "Betriebszeit",
    "Time Servers" : "Zeitserver",
    "Load" : "Auslastung",
    "Disk" : "Festplatte",
    "Mount" : "Mount",
    "Filesystem" : "Dateisystem",
    "Size" : "Größe",
    "Available" : "Verfügbar",
    "Used" : "Verwendet",
    "You will get a notification once one of your disks is nearly full." : "Du erhältst eine Benachrichtigung sobald eine Deiner Speichermedien fast voll ist.",
    "Files:" : "Dateien:",
    "Storages:" : "Speicher:",
    "Free Space:" : "Freier Speicherplatz:",
    "Network" : "Netzwerk",
    "Hostname" : "Host-Name",
    "DNS" : "DNS",
    "Gateway" : "Gateway",
    "Status" : "Status",
    "Speed" : "Geschwindigkeit",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktive Benutzer",
    "Total users:" : "Benutzer gesamt:",
    "Shares" : "Freigaben",
    "PHP" : "PHP",
    "Version:" : "Version:",
    "Memory Limit:" : "Arbeitspeicher-Grenzwert:",
    "Max Execution Time:" : "Maximale Ausführungszeit:",
    "Upload max size:" : "Maximale Größe zum Hochladen:",
    "Database" : "Datenbank",
    "Type:" : "Art:",
    "Size:" : "Größe:",
    "External monitoring tool" : "Externes Überwachungsprogramm",
    "You can connect an external monitoring tool by using this end point:" : "Durch Verwendung des folgenden Zugangspunktes kann ein externes Überwachungsprogramm verwendet werden: ",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Wenn Du \"?format=json\" am Ende der URL anhängst, erhältst Du das Ergebnis in JSON.",
    "Did you know?" : "Wusstest Du schon?",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON format!" : "Das Anhängen von \"?format=json\" am Ende der URL gibt Dir das Ergebnis im JSON-Format!"
},
"nplurals=2; plural=(n != 1);");
